@@ -14,40 +14,47 @@ def file_exist(file: str):
 
 def make_dir(file: str):
     path, _ = os.path.split(file)
-    if not os.path.exists(path):
+    if path and not os.path.exists(path):
         os.makedirs(path)
 
 
 def dump_json(
         obj: Any,
         file: str,
-        ensure_ascii:bool = False,
+        formatting: bool = False,
+        ensure_ascii: bool = False,
+        **kwargs,
 ) -> None:
     make_dir(file)
+    kwargs['ensure_ascii'] = ensure_ascii
+    if formatting:
+        kwargs['sort_keys'] = True
+        kwargs['indent'] = 4
+        kwargs['separators'] = (',', ':')
     with open(file, 'w', encoding='utf-8') as fw:
-        json.dump(obj, fw, ensure_ascii=ensure_ascii)
+        json.dump(obj, fw, **kwargs)
 
 
-def load_json(file: str) -> Any:
+def load_json(file: str, **kwargs,) -> Any:
     if not os.path.isfile(file):
         print('incorrect file path')
         raise FileExistsError
     with open(file, 'r', encoding='utf-8') as fr:
-        return json.load(fr)
+        return json.load(fr, **kwargs,)
 
 
-def dump_pickle(obj: Any, file: str) -> None:
+def dump_pickle(obj: Any, file: str, **kwargs) -> None:
     make_dir(file)
     with open(file, 'wb') as fw:
-        pickle.dump(obj, fw)
+        pickle.dump(obj, fw, **kwargs)
 
 
-def load_pickle(file: str) -> Any:
+def load_pickle(file: str, **kwargs) -> Any:
     if not os.path.isfile(file):
         print('incorrect file path')
         raise Exception
     with open(file, 'rb') as fr:
-        return pickle.load(fr)
+        return pickle.load(fr, **kwargs)
 
 
 def dump_lines(data: List[Any], file: str) -> None:
@@ -82,3 +89,8 @@ def load_excel(*args, **kwargs) -> List:
     df = pd.read_excel(*args, **kwargs)
     data = df.values
     return data
+
+
+if __name__ == '__main__':
+    x = [1,2,[2,4],{1:2,5:'222'}]
+    dump_json(x, 'test.json', formatting=True)
